/**
 * $Id: Synchronized.java,v 1.4 2009/12/19 22:34:08 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 13.11.2008 by oliver (ob@oasd.de)
 */
package patterntesting.annotation.concurrent;

import java.lang.annotation.*;
import java.util.concurrent.TimeUnit;

/**
 * Instead of synchronized methods you can mark these methods as
 * "@Synchronized". The SynchronizedAspect in patterntesting.concurrent
 * will use ReentrantLock to realize it and to avoid deadlocks.
 * If you set the log level to TRACE you can get additional information
 * about the locks and waiting threads.
 *
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 13.11.2008
 * @version $Revision: 1.4 $
 */
@Documented
@Target({ElementType.METHOD, ElementType.TYPE})
@Retention(RetentionPolicy.RUNTIME)
public @interface Synchronized {

    /**
     * The default timeout is 30 minutes (1800 seconds).
     * @return 1800 seconds as default timeout
     */
	long timeout() default 1800L;

	/**
	 * @return TimeUnit.SECONDS as default
	 */
	TimeUnit unit() default TimeUnit.SECONDS;

}

/**
 * $Log: Synchronized.java,v $
 * Revision 1.4  2009/12/19 22:34:08  oboehm
 * trailing spaces removed
 *
 * Revision 1.3  2009/12/14 17:14:30  oboehm
 * trailing tabs removed
 *
 * Revision 1.2  2009/09/25 14:49:43  oboehm
 * javadocs completed with the help of JAutodoc
 *
 * Revision 1.1  2009/03/24 08:38:26  oboehm
 * concurrent package moved to patterntesting-concurrent
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/annotation/concurrent/Synchronized.java,v $
 */
