/**
 * $Id: LogRuntimeException.java,v 1.4 2009/12/19 22:34:09 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 09.10.2008 by oliver (ob@oasd.de)
 */
package patterntesting.runtime.annotation;

import java.lang.annotation.*;

import org.apache.commons.logging.impl.SimpleLog;

/**
 * You want to see a RuntimeException in the log if it happens? Use this
 * annotation to mark those classes you want to be logged.
 *
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 09.10.2008
 * @version $Revision: 1.4 $
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.TYPE, ElementType.CONSTRUCTOR, ElementType.METHOD})
public @interface LogRuntimeException {

    /**
     * Normally a RuntimeException will be logged with "WARN" as log level.
     * If you want to change it you can do here.
     * @see SimpleLog (for the different log levels)
     */
	int value() default SimpleLog.LOG_LEVEL_WARN;

}

/*
 * $Log: LogRuntimeException.java,v $
 * Revision 1.4  2009/12/19 22:34:09  oboehm
 * trailing spaces removed
 *
 * Revision 1.3  2009/09/25 14:49:43  oboehm
 * javadocs completed with the help of JAutodoc
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/annotation/LogRuntimeException.java,v $
 */