/**
 * $Id: MBeanRegistry.java,v 1.3 2009/12/19 22:34:09 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 19.02.2009 by oliver (ob@oasd.de)
 */
package patterntesting.runtime.jmx;

import javax.management.*;

/**
 * To avoid confusion with the existing MBeanRegistration interface from
 * javax.management this interface is now called MBeanRegistry
 * (also there are too many negative associations with the word "registry").
 *
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 19.02.2009
 * @version $Revision: 1.3 $
 */
public interface MBeanRegistry {

    /**
     * Registers the MBean as "a.b.c:type=Xxx" (where "a.b.c" is the
     * package name and "Xxx" the classname).
     *
     * @throws JMException
     */
    public void registerAsMBean() throws JMException;

    /**
     * Register the MBean with the given name.
     *
     * @param name e.g. "a.b.c:type=Xxx"
     * @throws JMException
     */
    public void registerAsMBean(String name) throws JMException;

    /**
     * Register the MBean with the given object name.
     *
     * @param name e.g. new ObjectName("a.b.c:type=Xxx");
     * @throws JMException
     */
    public void registerAsMBean(ObjectName name) throws JMException;

    /**
     * Unregisters the MBean from the MBean server.
     */
    public void unregisterAsMBean();

    /**
     * Was the object registered as MBean?
     *
     * @return true if object was registered.
     */
    public boolean isRegisteredAsMBean();

    /**
     * Returns the MBean name under which this class was registered.
     *
     * @return e.g. "a.b.c:type=Xxx"
     */
    public String getMBeanName();

    /**
     * Returns the MBean name under which this class was registered.
     *
     * @return e.g. "a.b.c:type=Xxx" as ObjectName
     */
    public ObjectName getObjectName() throws MalformedObjectNameException;

}

/**
 * $Log: MBeanRegistry.java,v $
 * Revision 1.3  2009/12/19 22:34:09  oboehm
 * trailing spaces removed
 *
 * Revision 1.2  2009/02/23 21:57:38  oboehm
 * comments updated and one warning removed
 *
 * Revision 1.1  2009/02/20 21:34:03  oboehm
 * MBeanRegistry with default implementation added
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/jmx/MBeanRegistry.java,v $
 */
