/**
 * $Id: LogRecorder.java,v 1.5 2009/12/19 22:34:09 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 09.10.2008 by oliver (ob@oasd.de)
 */
package patterntesting.runtime.log;

import java.util.*;

import org.apache.commons.logging.Log;

import patterntesting.annotation.check.runtime.NullArgsAllowed;

/**
 * The Class LogRecorder which is able to record log messages.
 *
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 09.10.2008
 * @version $Revision: 1.5 $
 */
public class LogRecorder implements Log {

	private List<Object> objects = new ArrayList<Object>();
	private List<Throwable> exceptions = new ArrayList<Throwable>();
	private int n = 0;

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#debug(java.lang.Object)
	 */
	public void debug(Object arg0) {
		this.record(arg0);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#debug(java.lang.Object, java.lang.Throwable)
	 */
	public void debug(Object arg0, Throwable arg1) {
		this.record(arg0, arg1);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#error(java.lang.Object)
	 */
	public void error(Object arg0) {
		this.record(arg0);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#error(java.lang.Object, java.lang.Throwable)
	 */
	public void error(Object arg0, Throwable arg1) {
		this.record(arg0, arg1);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#fatal(java.lang.Object)
	 */
	public void fatal(Object arg0) {
		this.record(arg0);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#fatal(java.lang.Object, java.lang.Throwable)
	 */
	public void fatal(Object arg0, Throwable arg1) {
		this.record(arg0, arg1);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#info(java.lang.Object)
	 */
	public void info(Object arg0) {
		this.record(arg0);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#info(java.lang.Object, java.lang.Throwable)
	 */
	public void info(Object arg0, Throwable arg1) {
		this.record(arg0, arg1);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#isDebugEnabled()
	 */
	public boolean isDebugEnabled() {
		return false;
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#isErrorEnabled()
	 */
	public boolean isErrorEnabled() {
		return false;
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#isFatalEnabled()
	 */
	public boolean isFatalEnabled() {
		return false;
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#isInfoEnabled()
	 */
	public boolean isInfoEnabled() {
		return false;
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#isTraceEnabled()
	 */
	public boolean isTraceEnabled() {
		return false;
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#isWarnEnabled()
	 */
	public boolean isWarnEnabled() {
		return false;
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#trace(java.lang.Object)
	 */
	public void trace(Object arg0) {
		this.record(arg0);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#trace(java.lang.Object, java.lang.Throwable)
	 */
	public void trace(Object arg0, Throwable arg1) {
		this.record(arg0, arg1);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#warn(java.lang.Object)
	 */
	public void warn(Object arg0) {
		this.record(arg0);
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.logging.Log#warn(java.lang.Object, java.lang.Throwable)
	 */
	public void warn(Object arg0, Throwable arg1) {
		this.record(arg0, arg1);
	}

	/**
	 * Record.
	 *
	 * @param obj the obj
	 */
	private void record(Object obj) {
		this.record(obj, null);
	}

	/**
	 * Record.
	 *
	 * @param obj the obj
	 * @param t the t
	 */
	@NullArgsAllowed
	synchronized private void record(Object obj, Throwable t) {
		this.objects.add(obj);
		this.exceptions.add(t);
		this.n++;
	}

	/**
	 * Gets the text.
	 *
	 * @return the text
	 */
	public String getText() {
		String text = "";
		for (Object obj : this.objects) {
			text += obj;
		}
		return text.trim();
	}

	/**
	 * Gets the record.
	 *
	 * @return the record
	 */
	public String getRecord() {
		return getText();
	}

	/**
	 * Gets the number of records.
	 *
	 * @return the number of records
	 */
	public int getNumberOfRecords() {
		return n;
	}

    /* (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        String classname = this.getClass().getSimpleName();
        if (n == 1) {
            return classname + "(\"" + getRecord() + "\")";
        } else {
            return classname + " with " + n + " records";
        }
    }

}

/**
 * $Log: LogRecorder.java,v $
 * Revision 1.5  2009/12/19 22:34:09  oboehm
 * trailing spaces removed
 *
 * Revision 1.4  2009/12/14 17:14:31  oboehm
 * trailing tabs removed
 *
 * Revision 1.3  2009/09/25 14:49:44  oboehm
 * javadocs completed with the help of JAutodoc
 *
 * Revision 1.2  2009/03/24 21:00:42  oboehm
 * moved to patterntesting.annotation.check.runtime
 *
 * Revision 1.1  2009/03/12 21:31:17  oboehm
 * LogRecorder moved to src/main
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/log/LogRecorder.java,v $
 */
